@@ -61,7 +61,7 @@ sub execute {
     my $in_fh = IO::Zlib->new( $args->[0], "rb" );
     my $out_fh;
     if ( lc( $opt->{outfile} ) eq "stdout" ) {
-        $out_fh = *STDOUT;
+        $out_fh = \*STDOUT;
     }
     else {
         open $out_fh, ">", $opt->{outfile};
